﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class ParticleScript : MonoBehaviour
{
    // state
    public Vector3 pNow;
    Vector3 pOld;

    // constants
    public float mass = 0.5f;
    float drag = 0.98f; // 98% of velocity is lost PER SECOND

    // Start is called before the first frame update
    void Start()
    {
        pNow = this.transform.localPosition;
        pOld = pNow; // starts with no velocity 
    }

    
    void FixedUpdate()
    {

        // Verlet integration
        float dt = Time.fixedDeltaTime;
        Vector3 f = Vector3.down * 4.8f * mass; // gravity

        Vector3 a = f / mass;
        float dump = 1 - drag * dt; // how much of the speed is prereved. If dump=0.98, preserve 98% of velocity
        Vector3 pNext = (1+dump)*pNow - dump*pOld + a * dt*dt; 

        pOld = pNow;
        pNow = pNext;

        //EnforceMyPositionalConstraints(); // (moved in the global script)

    }

    public void EnforceMyPositionalConstraints(){
        // plase don's sink into the plane
        if (pNow.y < 0.1f ) pNow.y = 0.1f;

        // please stay inside the box
        pNow.x = Mathf.Clamp(pNow.x,-5,+5); // if x<-5 then x = -5 ; if x>5 x = 5
        pNow.z = Mathf.Clamp(pNow.z,-5,+5); 
    }

    void Update(){
        pNow = transform.localPosition;
    }

    void LateUpdate(){
        transform.localPosition = pNow; // from our "Physics engine" to Unity rendering
        
    }
}
